==> jc-1.4.0.tar.gz: gnu/xml/transform/DOMSourceLocator.h <==
// class gnu.xml.transform.DOMSourceLocator

// class file dependencies
// @dep_class 75c3787362710d9b gnu_xml_transform_DOMSourceLocator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_DOMSourceLocator_H_
#define _JC_gnu_xml_transform_DOMSourceLocator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$sub_refs	_jc_gnu_xml_transform_DOMSourceLocator$sub_refs;
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$sub_nonrefs	_jc_gnu_xml_transform_DOMSourceLocator$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$refs	_jc_gnu_xml_transform_DOMSourceLocator$refs;
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$nonrefs	_jc_gnu_xml_transform_DOMSourceLocator$nonrefs;
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$object	_jc_gnu_xml_transform_DOMSourceLocator$object;

typedef const struct _jc_gnu_xml_transform_DOMSourceLocator$vmethods	_jc_gnu_xml_transform_DOMSourceLocator$vmethods;
typedef const struct _jc_gnu_xml_transform_DOMSourceLocator$vtable	_jc_gnu_xml_transform_DOMSourceLocator$vtable;
typedef const struct _jc_gnu_xml_transform_DOMSourceLocator$vtype	_jc_gnu_xml_transform_DOMSourceLocator$vtype;

// Constructors
extern void _jc_gnu_xml_transform_DOMSourceLocator$method$_init$ea4cfa151ae11b7c(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_gnu_xml_transform_DOMSourceLocator$method$getColumnNumber$b311b369fd1c2551(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
extern jint _jc_gnu_xml_transform_DOMSourceLocator$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
extern struct _jc_object *_jc_gnu_xml_transform_DOMSourceLocator$method$getOriginatingNode$8bf792e6c40199c8(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_DOMSourceLocator$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_DOMSourceLocator$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getColumnNumber$b311b369fd1c2551;
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getOriginatingNode$8bf792e6c40199c8;
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getSystemId$dfda7e64149e1929;

// Virtual methods structure
struct _jc_gnu_xml_transform_DOMSourceLocator$vmethods {
	jint	(*getColumnNumber$b311b369fd1c2551)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
	struct _jc_object	*(*getOriginatingNode$8bf792e6c40199c8)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *);
};

// Vtable
struct _jc_gnu_xml_transform_DOMSourceLocator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_DOMSourceLocator$vmethods	gnu_xml_transform_DOMSourceLocator;
};

// Vtype
struct _jc_gnu_xml_transform_DOMSourceLocator$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_DOMSourceLocator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_DOMSourceLocator$sub_refs {
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_DOMSourceLocator$refs {
    _jc_gnu_xml_transform_DOMSourceLocator$sub_refs	gnu_xml_transform_DOMSourceLocator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_DOMSourceLocator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_DOMSourceLocator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_DOMSourceLocator$sub_nonrefs	gnu_xml_transform_DOMSourceLocator;
};

// Object instance structure
struct _jc_gnu_xml_transform_DOMSourceLocator$object {
	_jc_gnu_xml_transform_DOMSourceLocator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_DOMSourceLocator$vtype	*vtype;
	_jc_gnu_xml_transform_DOMSourceLocator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_DOMSourceLocator$vtype _jc_gnu_xml_transform_DOMSourceLocator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_DOMSourceLocator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_DOMSourceLocator$class_object;

#endif	/* _JC_gnu_xml_transform_DOMSourceLocator_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/transform/DOMSourceLocator.h <==
// class gnu.xml.transform.DOMSourceLocator

// class file dependencies
// @dep_class 75c3787362710d9b gnu_xml_transform_DOMSourceLocator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_DOMSourceLocator_H_
#define _JC_gnu_xml_transform_DOMSourceLocator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$sub_refs	_jc_gnu_xml_transform_DOMSourceLocator$sub_refs;
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$sub_nonrefs	_jc_gnu_xml_transform_DOMSourceLocator$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$refs	_jc_gnu_xml_transform_DOMSourceLocator$refs;
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$nonrefs	_jc_gnu_xml_transform_DOMSourceLocator$nonrefs;
typedef struct _jc_gnu_xml_transform_DOMSourceLocator$object	_jc_gnu_xml_transform_DOMSourceLocator$object;

typedef const struct _jc_gnu_xml_transform_DOMSourceLocator$vmethods	_jc_gnu_xml_transform_DOMSourceLocator$vmethods;
typedef const struct _jc_gnu_xml_transform_DOMSourceLocator$vtable	_jc_gnu_xml_transform_DOMSourceLocator$vtable;
typedef const struct _jc_gnu_xml_transform_DOMSourceLocator$vtype	_jc_gnu_xml_transform_DOMSourceLocator$vtype;

// Constructors
extern void _jc_gnu_xml_transform_DOMSourceLocator$method$_init$ea4cfa151ae11b7c(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_xml_transform_DOMSourceLocator$method$getColumnNumber$b311b369fd1c2551(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_transform_DOMSourceLocator$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_transform_DOMSourceLocator$method$getOriginatingNode$8bf792e6c40199c8(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_DOMSourceLocator$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_DOMSourceLocator$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getColumnNumber$b311b369fd1c2551;
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getOriginatingNode$8bf792e6c40199c8;
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_transform_DOMSourceLocator$method_info$getSystemId$dfda7e64149e1929;

// Virtual methods structure
struct _jc_gnu_xml_transform_DOMSourceLocator$vmethods {
	jint	(*getColumnNumber$b311b369fd1c2551)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getOriginatingNode$8bf792e6c40199c8)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_transform_DOMSourceLocator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_DOMSourceLocator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_DOMSourceLocator$vmethods	gnu_xml_transform_DOMSourceLocator;
};

// Vtype
struct _jc_gnu_xml_transform_DOMSourceLocator$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_DOMSourceLocator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_DOMSourceLocator$sub_refs {
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_DOMSourceLocator$refs {
    _jc_gnu_xml_transform_DOMSourceLocator$sub_refs	gnu_xml_transform_DOMSourceLocator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_DOMSourceLocator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_DOMSourceLocator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_DOMSourceLocator$sub_nonrefs	gnu_xml_transform_DOMSourceLocator;
};

// Object instance structure
struct _jc_gnu_xml_transform_DOMSourceLocator$object {
	_jc_gnu_xml_transform_DOMSourceLocator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_DOMSourceLocator$vtype	*vtype;
	_jc_gnu_xml_transform_DOMSourceLocator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_DOMSourceLocator$vtype _jc_gnu_xml_transform_DOMSourceLocator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_DOMSourceLocator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_DOMSourceLocator$class_object;

#endif	/* _JC_gnu_xml_transform_DOMSourceLocator_H_ */
